Practice Problems
-----------------------------------------------------

Please answer the following problems to the best
of your ability without any outside help. You can stop working on question after you worked on it for
about five minutes without solving it.

Please do not ask for external help and try your best to finish it!

Problems
==============
.. selectquestion:: song-sq-pp-iso
   :fromid: Classes_Basic_Song_ac, Classes_Basic_Song_pp_iso
   :toggle: lock
   :points: 10

.. poll:: pp-iso-poll-cls-1
    :scale: 9

    From 1-lowest to 9-highest, how useful was the Parsons problem in helping you <b>solve</b> this problem? Please skip this question if you didn't use it.


.. shortanswer:: pp-iso-sa-cls-1

    Please explain your rating above or explain why you didn’t use the Parsons problem to help you solve the write-code problem.

.. selectquestion:: book-sq-pp-iso
   :fromid: Classes_Basic_Book_ac, Classes_Basic_Book_pp_iso
   :toggle: lock
   :points: 10

.. poll:: pp-iso-poll-cls-2
    :scale: 9

    From 1-lowest to 9-highest, how useful was the Parsons problem in helping you <b>solve</b> this problem? Please skip this question if you didn't use it.

.. shortanswer:: pp-iso-sa-cls-2

    Please explain your rating above or explain why you didn’t use the Parsons problem to help you solve the write-code problem.


.. selectquestion:: cat-sq-pp-iso
   :fromid: Classes_Basic_Cat_ac, Classes_Basic_Cat_pp_iso
   :toggle: lock
   :points: 10

.. poll:: pp-iso-poll-cls-3
    :scale: 9

    From 1-lowest to 9-highest, how useful was the Parsons problem in helping you <b>solve</b> this problem? Please skip this question if you didn't use it.

.. shortanswer:: pp-iso-sa-cls-3

    Please explain your rating above or explain why you didn’t use the Parsons problem to help you solve the write-code problem.

.. selectquestion:: account-sq-pp-iso
   :fromid: Classes_Basic_Account_ac, Classes_Basic_Account_pp_iso
   :toggle: lock
   :points: 10

.. poll:: pp-iso-poll-cls-4
    :scale: 9

    From 1-lowest to 9-highest, how useful was the Parsons problem in helping you <b>solve</b> this problem? Please skip this question if you didn't use it.

.. shortanswer:: pp-iso-sa-cls-4

    Please explain your rating above or explain why you didn’t use the Parsons problem to help you solve the write-code problem.


.. selectquestion:: fortuneteller-sq-pp-iso
   :fromid: Classes_Basic_FortuneTeller_ac, Classes_Basic_FortuneTeller_pp_iso
   :toggle: lock
   :points: 10

.. poll:: pp-iso-poll-cls-5
    :scale: 9

    From 1-lowest to 9-highest, how useful was the Parsons problem in helping you <b>solve</b> this problem? Please skip this question if you didn't use it.

.. shortanswer:: pp-iso-sa-cls-5

    Please explain your rating above or explain why you didn’t use the Parsons problem to help you solve the write-code problem.


What to do next
============================
.. raw:: html
    
   <h4>Click on the following link to finish a posttest 👉 <b><a href="posttest-cls.html">Post Test</b></h4>
